@@ -1,6 +1,6 @@
 /*
  * Caudium - An extensible World Wide Web server
- * Copyright  2000-2001 The Caudium Group
+ * Copyright  2000-2004 The Caudium Group
  * Based on IMHO  Stefan Wallstrm and Bosse Lincoln.
  * 
  * This program is free software; you can redistribute it and/or
@@ -19,41 +19,37 @@
  *
  */
 /*
- * $Id: defaultlanguage.h,v 1.8.2.1.2.1 2001/09/30 23:31:07 kiwi Exp $
+ * $Id: defaultlanguage.h,v 1.49.2.1 2004/01/21 11:57:28 vida Exp $
  */
 
-// 
+#ifndef __DEFAULTLANGUAGE_H
+#define __DEFAULTLANGUAGE_H
+
+//
 // Messages / Default language
 //
 
-string msg (mapping sessobj, int m, array arg)
+string default_msg (int m, array arg)
 {
-  if (sessobj) {
-    object lang_prog = lang_progs[sessobj->language];
-    if (lang_prog) {
-      string s = lang_prog->msg (sessobj, m, arg);
-      if (s && (String.width(s)==8) && (lang_charsets[sessobj->language] || "iso-8859-1" != "iso-8859-1"))
-	s = Locale.Charset.decoder (lang_charsets[sessobj->language])->feed (s)->drain ();
-      if (s)
-	return s;
-    }
-  }
-
   switch(m) {
   case M_LOGIN:
     return "Login:";
   case M_PASSWORD:
     return "Password:";
+  case M_IMAPSERVER:
+    return "IMAP server:";
+  case M_PORT:
+    return "Port:";
   case M_NOLOGIN:
     return sprintf ("<b>Could not log in:</b> %s", @arg);
   case M_LOGINERROR:
     return "Wrong login or password. Try again. ";
   case M_IMAPERROR:
     return "There was a problem talking to the mail (IMAP) server. "
-      "Please contact the administrator.";
+           "Please contact the administrator.";
   case M_SMTPERROR:
-    return "There was a problem talking to the outgoing mail (SMTP) server, "
-      "and the mail was not sent. The recipient of the mail might not exist.";
+    return sprintf("There was a problem talking to the outgoing mail (SMTP) server, "
+           "and the mail was not sent to %s. The recipient of the mail might not exist.", @arg);
   case M_SMTPOK:
     return sprintf ("The mail \"%s\" was sent to: %s", @arg);
   case M_SAVEDUSERINTERFACE:
@@ -62,6 +58,8 @@ string msg (mapping sessobj, int m, array arg)
     return "User interface:";
   case M_LOGIN_OK:
     return "OK";
+  case M_ADDRBOOKERRROR:
+    return "There was a problem talking to the address book server (LDAP)";
 
   case M_NEWMAIL:
     return "Compose";
@@ -75,6 +73,10 @@ string msg (mapping sessobj, int m, array arg)
     return "Preferences";
   case M_LOGOUT:
     return "Logout";
+  case M_LOGOUTCLOSE:
+    return "Close this browser window to make sure no one can read your mail.";
+  case M_LOGOUTRELOAD:
+    return "Reload this page to login.";
   case M_CURRMAILBOX:
     return "Current Mailbox";
   case M_CHECKACTIVEMAILBOXES:
@@ -98,7 +100,9 @@ string msg (mapping sessobj, int m, array arg)
     return "Date";
   case M_DELAY:
     return "Delay";
-  
+  case M_RECEIVED:
+    return "Received";
+
   case  M_MARKFLAG:
     return "M";
   case M_NEWFLAG:
@@ -124,7 +128,7 @@ string msg (mapping sessobj, int m, array arg)
   case M_NOATTACHMENTS:
     return "No attachments";
   case M_ADDATTACHMENT:
-    return "Add attachment...";
+    return "Add attachment";
   case M_REMOVEMARKEDATTACHMENTS:
     return "Remove marked attachments";
   case M_UPLOADATTACHMENT:
@@ -154,12 +158,22 @@ string msg (mapping sessobj, int m, array arg)
   case M_SENDBROKENADDR:
     return(sprintf("The address \"%s\" is not a correct email address. Please correct it and try again.", arg[0]));
   case M_SAVEMAILCOPY:
-    return("Save a copy");  
+    return("Save a copy");
+  case M_SENDBLIND:
+    return ("Recipients don't see each other");
+  case M_PSENDBLIND:
+    return ("Recipients don't see each other button");
+  case M_SEARCHREPLACE:
+    return ("Search and replace");
+  case M_CHECKBCC:
+    return ("Send blind copy to administrator");
 
   case M_DELETEMARKED:
     return "Delete marked";
   case M_MOVEMARKED:
     return "Move marked to";
+  case M_ARCHIVE:
+    return "Archive";
   case M_SELECTMBOX:
     return "(Select a mailbox)";
   case M_CHECKNEWMAIL:
@@ -168,8 +182,16 @@ string msg (mapping sessobj, int m, array arg)
     return sprintf("Mail %d-%d of %d", @arg);
   case M_BACKN:
     return sprintf("[<< Prev %d]", @arg);
+  case M_EBACKN:
+    return "Prev";
   case M_FORWARDN:
     return sprintf("[Next %d >>]", @arg);
+  case M_EFORWARDN:
+    return "Next";
+  case M_SENDMARKEDDRAFTS:
+    return "Send marked drafts";
+  case M_SENDMARKEDDRAFTSMOVE:
+    return "Send marked drafts and move";
   case M_NUMBER:
     return "#";
   case M_DELETEMARKEDP:
@@ -186,6 +208,12 @@ string msg (mapping sessobj, int m, array arg)
     return "[No mail]";
   case M_MARKALL:
     return "Mark all";
+  case M_HISTFLAG:
+    return "History";
+  case M_HISTSEARCH:
+    return "Search in history";
+  case M_THREADSHOW:
+    return "Thread";
 
   case M_MBOXNAME:
     return "Mailbox (m/r/u/s)";
@@ -213,10 +241,20 @@ string msg (mapping sessobj, int m, array arg)
     return "Path:";
   case M_BOXTRASH:
     return "Trash";
+  case M_SHARED_BOXTRASH:
+    return "Trash";
   case M_BOXSENTMAIL:
     return "Sent";
+  case M_SHARED_BOXSENTMAIL:
+    return "Sent";
   case M_BOXDRAFTS:
     return "Drafts";
+  case M_SHARED_BOXDRAFTS:
+    return "Drafts";
+  case M_BOXANSWERED:
+    return "Answered";
+  case M_SHARED_BOXANSWERED:
+    return "Answered";
   case M_RENAMEMBOX:
     return "Rename a mailbox";
   case M_RENAMEMBOXERROR:
@@ -247,6 +285,8 @@ string msg (mapping sessobj, int m, array arg)
     return "Mail searchpath";
   case M_PINCLUDEMAIL:
     return "Include mail when replying";
+	case M_PREPLYONTOP:
+		return "Reply on top of the message";
   case M_PQUOTEPREFIX :
     return "Prefix";
   case M_PSIGNATURE:
@@ -260,9 +300,11 @@ string msg (mapping sessobj, int m, array arg)
   case M_PSORTORDER:
     return "Mail sort order";
   case M_PSORTORDERS:
-    return ([ "forward": "forward", "backward":"backward"])[arg[0]];
+return ([ "forward": "forward", "backward":"backward"])[arg[0]];
   case M_PTRASHFOLDER:
     return "Trash folder";
+  case M_PANSWEREDFOLDER:
+    return "Answered mail folder";
   case M_PSENTFOLDER:
     return "Sent mail folder";
   case M_PDRAFTSFOLDER:
@@ -281,14 +323,20 @@ string msg (mapping sessobj, int m, array arg)
     return "(Lines with headers in this format: header:value )";
   case M_PSORTCOLUMN:
     return "Sort on column";
-  case M_PSHOWHTML:                                                  
+  case M_PSHOWHTML:
     return "Show HTML messages";
-  case M_PSHOWTEXT:                                                  
+  case M_PSHOWTEXT:
     return "Show text messages";
   case M_PSHOWHIDDENHEADERS:
     return "Enable <i>\"Show full headers\"</i>-button";
+  case M_PAUTOFILTER:
+    return "With this option a rule is automatically build when you move a mail to a specified mailbox. When the same sender come back,  his mail is moved to the mailbox you already specified";
   case M_PADDRESSBOOK:
     return "Default addressbook (not extended)";
+  case M_PPOSTLOGINSCREEN:
+    return "Default screen after successful login";
+  case M_PENABLEDISABLECACHEFEEDER:
+    return "Enable or disable the background IMAP client started after your login. If the background IMAP client is enable, some features like fast search or faster mailboxes browsing are avaible. However the interface will be slower for a few minutes after you logged in.";
 
   case M_SPELLDONE:
     return "Done";
@@ -296,13 +344,17 @@ string msg (mapping sessobj, int m, array arg)
     return "Previous";
   case M_SPELLNEXT:
     return "Next";
-  case  M_SPELLCHANGETO:
+  case M_SPELLCHANGETO:
     return "Change to";
   case M_SPELLSUGGESTIONS:
     return "Suggestions";
+  case M_NOSPELLINGERRORS:
+    return "No spelling errors found.";
+  case M_MANUALCORRECTION:
+    return "Manual correction";
 
   case M_LOGOUTMSG:
-    return "<b>You are logged out.</b> Close this browser window to make sure no one can read your mail.<br /><br />Reload this page to login.";
+    return "You have been logged out.";
   case M_LOGGEDOUT:
     return "Logged out";
 
@@ -313,6 +365,10 @@ string msg (mapping sessobj, int m, array arg)
 
   case M_REPLY:
     return "Reply";
+  case M_REPLYMARKED:
+    return "Reply selected mails";
+  case M_REPLYMOVEMARKED:
+    return "Reply and move selected mails";
   case M_READPREV:
     return "Read previous";
   case M_READNEXT:
@@ -327,8 +383,14 @@ string msg (mapping sessobj, int m, array arg)
     return "Delete";
   case M_FORWARD:
     return "Forward";
+  case M_FORWARDMOVE:
+    return "Forward and move";
   case M_CONTINUECOMPOSE:
-    return "Continue...";
+    return "Continue";
+  case M_CONTINUECOMPOSEMOVE:
+    return "Continue and move";
+  case M_BACKTOMAILINDEX:
+    return "Back to mail list";
   case M_NOTIFYTO:
     return sprintf ("%s requested a receipt to be returned. Do you wish to send one ?", @arg);
   case M_MAIL:
@@ -341,15 +403,19 @@ string msg (mapping sessobj, int m, array arg)
     return "Mail is too big to be shown. Click here to download it.";
   case M_REPLYTOALL:
     return "Reply to all";
+  case M_REPLYMOVE:
+    return "Reply and move";
+  case M_REPLYTOALLMOVE:
+    return "Reply to all and move";
   case M_MOVETHISTOTRASH:
     return "Move to trash";
   case M_CHARSETWARNING:
     return sprintf("Warning! Unable to decode the characterset \"%s\". Message is presented undecoded.",@arg);
 
-  case M_ADDRESSBOOKTITLE: 
-    return("Address Book");         
+  case M_ADDRESSBOOKTITLE:
+    return("Address Book");
   case M_ADDRESSBOOK:
-    return("Address book...");
+    return("Address book");
   case M_INDEXNAMERECIPIENT:
     return("Index name (click to add as recipient)");
   case M_INDEXNAMEEDIT:
@@ -359,7 +425,7 @@ string msg (mapping sessobj, int m, array arg)
   case M_NOADDRESSES:
     return("No addresses");
   case M_NEWADDRESS:
-    return("New address...");
+    return("New address");
   case M_EDITADDRESS:
     return("Edit address");
   case M_ADDADDRESS:
@@ -372,22 +438,74 @@ string msg (mapping sessobj, int m, array arg)
     return("Save and use");
   case M_DELETEADDRESS:
     return("Delete address");
+  case M_DELETEALLADDRESS:
+    return("Delete all addressbook");
   case M_CANCELADDRESS:
     return("Cancel");
   case M_CANNOTIMPORT:
     return("Cannot import this addressbook, since its\nformat is not recognized.");
+  case M_MUSTSELECTFIELD:
+    return("You must specify at least the field(s)");
   case M_IMPORTADDRESSBOOKTITLE:
     return("Import address book");
   case M_UPLOADADDRESSBOOK:
-    return("Upload a Pine, exported Netscape (.ldif) or Outlook (.csv) address book");
+    return("Upload a Pine, an exported Netscape (.ldif) or Outlook (.csv) address book");
   case M_PINELOCATION:
     return("The Pine address book is often in ~/.addressbook");
   case M_UPLOADANDIMPORT:
     return("Upload and import");
   case M_IMPORTADDRESSBOOK:
-    return("Import address book...");
+    return("Import address book");
   case M_GLOBALADDRESSES:
     return("Common addresses:");
+  case M_SELECT:
+    return("Select");
+  case M_EMAILADDRESS:
+    return("Email address");
+  case M_SURNAME:
+    return("Surname");
+  case M_NICKNAME:
+    return("Nickname");
+  case M_HOMEPHONE:
+    return("Home phone");
+  case M_WORKPHONE:
+    return("Work phone");
+  case M_WORKSTATE:
+    return("Work state");
+  case M_TITLE:
+    return("Title");
+  case M_COMPANY:
+    return("Company");
+  case M_DEPARTMENT:
+    return("Department");
+  case M_HOMEPOSTALADDRESS:
+    return ("Home postal address");
+  case M_WORKPOSTALADDRESS:
+    return("Work postal address");
+  case M_WORKCITY:
+    return("Work city");
+  case M_WORKCOUNTRY:
+    return("Work country");
+  case M_PAGER:
+    return("Pager");
+  case M_MOBILE:
+    return("Mobile");
+  case M_URI:
+    return("URI");
+  case M_DESCRIPTION:
+    return("Description");
+  case M_POSTALCODE:
+    return("Postal code");
+  case M_DESTINATIONIMPORT:
+    return("Destination to import to");
+  case M_SELECTMATCHINGFIELDS:
+    return("Select matching fields");
+  case M_IMPORTEDFIELDS:
+    return("Imported fields");
+  case M_AVAILABLEFIELDS:
+    return ("Available fields");
+  case M_ADDRESSBOOKWRITEPROBLEM:
+    return("Problem while writing to address book");
 
   case M_LDAPTITLE:
     return("LDAP addresses");
@@ -401,16 +519,14 @@ string msg (mapping sessobj, int m, array arg)
     return("OU");
 
   case M_MAILNOTIFYWINDOW:
-    return("Mail notification...");
+    return("Mail notification");
   case M_GETNEWMAIL:
-    return("Get new mail...");
+    return("Get new mail");
 
   case M_SEARCHMAILTITLE:
     return("Search mail");
   case M_SEARCHMAIL:
-    return("Search...");
-  case M_SEARCHMAILBOX:
-    return(sprintf("Find mail in mailbox <b>%s</b> which contains",arg[0]));
+    return("Search");
   case M_SEARCHANYWHERE:
     return("anywhere");
   case M_SEARCHFROMFIELD:
@@ -419,13 +535,27 @@ string msg (mapping sessobj, int m, array arg)
     return("in 'to' field");
   case M_SEARCHSUBJECT:
     return("in subject");
+  case M_SEARCHHEADERS:
+    return("in all headers"); 
   case M_SEARCHBODY:
     return("in mail body");
   case M_SEARCHAND:
     return("AND");
   case M_SEARCHSHOWINGMAIL:
     return("Showing mail with ");
-
+  case M_NOSEARCHRESULTS:
+    return("No answers matching you query");
+  case M_NOSEARCHREMEMBER:
+    return "Don't remember the previous search";
+  case M_SEARCHALLMBOX:
+    return "Search in all mailboxes";
+  case M_SHOWALLAFTERSEARCH:
+    return "Show all";
+  case M_STICKYFILTER:
+    return "Sticky Filter";
+  case M_SEARCHCACHENOTFEEDED:
+    return "You can't search multiple mailboxes for now, please wait a few "
+    "moments if you want this feature";
   case M_YES:
     return "Yes";
   case M_NO:
@@ -437,8 +567,8 @@ string msg (mapping sessobj, int m, array arg)
 
   case M_PADDRESSBOOKFILTER:
     return "Default filterbook (not extended)";
-  case M_FILTERBOOKTITLE: 
-    return("Mail Filter");         
+  case M_FILTERBOOKTITLE:
+    return("Mail Filter");
   case M_EMPTYADDRESSFILTER:
     return "You must specify non-empty index folder and filter(s).";
   case M_NOADDRESSESFILTER:
@@ -454,7 +584,7 @@ string msg (mapping sessobj, int m, array arg)
   case M_INDEXNAMEEDITFIELDFILTER:
     return("Index field");
   case M_NEWADDRESSFILTER:
-    return("New filter...");
+    return("New filter");
   case M_SAVEADDRESSFILTER:
     return("Save and use");
   case M_DELETEADDRESSFILTER:
@@ -479,12 +609,29 @@ string msg (mapping sessobj, int m, array arg)
   case M_PORGANIZATION:
     return "Organization";
 
+  case M_TOTALSIZE:
+    return "Total size";
+  case M_OF:
+    return "of";
+  case M_USED:
+    return "used";
+  case M_FOLDER:
+    return "Folder";
+  case M_MESSAGES:
+    return "Messages";
+  case M_UNSEEN:
+    return "Unseen";
+  case M_NEW:
+    return "New";
+  case M_QUOTA:
+    return "Quota";
+
   case M_MDNMESSAGE:
     return sprintf("This is a Return Receipt for the mail that you sent to %s. "
-		   "Note: this Return Receipt only acknowledges that the message was "
-		   "displayed on the recipient's machine. There is no guarantee that the "
-		   "content has been read or understood.", @arg);
- 
+                   "Note: this Return Receipt only acknowledges that the message was "
+                   "displayed on the recipient's machine. There is no guarantee that the "
+                   "content has been read or understood.", @arg);
+
   case M_MDNHEADER:
     return "Return Receipt (displayed) - ";
 
@@ -507,6 +654,65 @@ string msg (mapping sessobj, int m, array arg)
 
   case M_ENDSESSION:
     return "End the CAMAS session ?";
+
+  case M_FWD_SEP:
+    return "------ Forwarded message ------";
+  case M_FWD_CC:
+    return "Cc: ";
+  case M_FWD_DATE:
+    return "Date: ";
+  case M_FWD_FROM:
+    return "From: ";
+  case M_FWD_REPLYTO:
+    return "Reply-To: ";
+  case M_FWD_SUBJECT:
+    return "Fwd: ";
+  case M_FWD_TO:
+    return "To: ";
+  case M_FWD_REP_SEP:
+    return "-------------";
   }
   return " ** MISSING MESSAGE ** ";
 }
+
+string msg (object sessobj, int m, array arg)
+{
+  string s;
+  if (sessobj) {
+    object lang_prog = lang_progs[sessobj->language];
+    if (lang_prog) {
+      s = lang_prog->msg (sessobj, m, arg);
+      if (s && lang_charsets[sessobj->language])
+        s = Locale.Charset.decoder (lang_charsets[sessobj->language])->feed (s)->drain ();
+      if (s)
+      {
+#if constant(String.Elite) 
+        if(QUERY(leetp))
+          s = String.Elite.elite_string(s, QUERY(leetp));
+#endif
+        return s;
+      }
+    }
+  }
+  s = default_msg(m, arg);
+#if constant(String.Elite)  
+  if(QUERY(leetp)) 
+    s = String.Elite.elite_string(s, QUERY(leetp));
+#endif 
+  return s;
+}
+
+#endif // __DEFAULTLANGUAGE_H
+
+/*                                                                             
+ * If you visit a file that doesn't contain these lines at its end, please     
+ * cut and paste everything from here to that file.                            
+ */                                                                            
+                                                                               
+/*                                                                             
+ * Local Variables:                                                            
+ * c-basic-offset: 2                                                           
+ * End:                                                                        
+ *                                                                             
+ * vim: softtabstop=2 tabstop=2 expandtab autoindent formatoptions=croqlt smartindent cindent shiftwidth=2
+ */
