@@ -1,6 +1,6 @@
 /*
  * Caudium - An extensible World Wide Web server
- * Copyright  2000-2001 The Caudium Group
+ * Copyright  2000-2004 The Caudium Group
  * Based on IMHO  Stefan Wallstrm and Bosse Lincoln.
  *
  * This program is free software; you can redistribute it and/or
@@ -19,10 +19,23 @@
  *
  */
 /*
- * $Id: parser.h,v 1.2 2001/01/13 04:16:31 neotron Exp $
+ * $Id: parser.h,v 1.10 2004/01/13 11:01:37 vida Exp $
  */
 
+#ifndef __PARSER_H
+#define __PARSER_H
+
 #define PT_MAPPING 0
 #define PT_LIST 1
 #define PT_QSTR 2
 #define PT_TOKENS 3
+
+#endif __PARSER_H
+/*                                                                             
+ * Local Variables:                                                            
+ * c-basic-offset: 2                                                           
+ * End:                                                                        
+ *                                                                             
+ * vim: softtabstop=2 tabstop=2 expandtab autoindent formatoptions=croqlt smartindent cindent shiftwidth=2
+ */
+
